@@ -1,9 +1,10 @@
 from .abstractLogMessages import *
 from .abstractAccountKeysManager import *
 from .abstractInstructionManager import *
+from mabstract_apis import get_response,requests
 class TransactionProcessor:
     def __init__(self, txnData=None,signature=None,instruction_mgr = None,account_mgr=None,log_mgr=None,**kwargs):
-        txnData = txnData or self.getTransacion(signature,**kwargs)
+        txnData = txnData or self.make_txn_request(signature,**kwargs)
         self.txnData = txnData
         self.log_mgr = log_mgr or logMessageManager(txnData)
         self.account_mgr = account_mgr or saveAcountKeys(txnData)
