@@ -14,7 +14,7 @@ def get_account_keys(txnData):
     return txnData.get('transaction', {}).get('message', {}).get('accountKeys', [])
 
 def get_loaded_addresses(txnData):
-    return txnData.get('meta', {}).get('loadedAddresses', [])
+    return txnData['meta']['loadedAddresses']
 
 def get_read_only_addresses(txnData):
     return get_loaded_addresses(txnData).get('readonly', [])
@@ -23,7 +23,7 @@ def get_writable_addresses(txnData):
     return get_loaded_addresses(txnData).get('writable', [])
 
 def get_log_messages(txnData):
-    return txnData.get('meta', {}).get('logMessages', [])
+    return txnData['meta']['logMessages']
 
 def get_instructions(txnData):
   return txnData['transaction']['message']['instructions']
